pub trait PartitionWrite<L: Level> {
// Required methods
fn insert(&mut self, value: L::Value) -> bool;
fn remove(&mut self, value: L::Value) -> bool;
fn remove_range<R: RangeBounds<L::Value>>(&mut self, values: R);
}Required Methods
Sourcefn insert(&mut self, value: L::Value) -> bool
fn insert(&mut self, value: L::Value) -> bool
Inserts the value into the partition unless it already exists.
Returns true if the insertion occurred, false otherwise.
Sourcefn remove(&mut self, value: L::Value) -> bool
fn remove(&mut self, value: L::Value) -> bool
Removes the value from the partition if it exists.
Returns true if the removal occurred, false otherwise.
Sourcefn remove_range<R: RangeBounds<L::Value>>(&mut self, values: R)
fn remove_range<R: RangeBounds<L::Value>>(&mut self, values: R)
Removes a range of values from the partition.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".